# Example 1 in the manuscript: workforce data 

options(width=68, digits=5)

# Load VGAM for R 
library(VGAM, lib.loc = "/home/yee/myRlibs")  # Change path!

# Read in the workforce data

#attach("/home/yee/VGAM6") # Change path!  # Use if Splus6

source("./workforce.R")



null =   vglm(marital ~ 1, multinomial, data=workforce, tr=T, cr="d")
summary(null)
    
null2=   vglm(marital ~ age30 + logedu1, multinomial, eps=1e-8,
              data=workforce, tr=T, cr="d")
summary(null2)

# Rank-1 RR-MLM
set.seed(123)
fit1 = rrvglm(marital ~ age30 + logedu1 + 
                        binge + smokenow + sun + nerves + nervous + 
                        hurt + tense + miserable + fedup +
                        worry + worrier + mood,
              multinomial,
              norrr = ~ age30 + logedu1,
              rank=1,
              Crit="coef", linesearch=F,
              Cindex=2,
              maxit=7, eps=1e-8,
              data=workforce, trace=T, cr="dev")

coef(fit1)

# This displays the C matrix nicely:
round(coef(fit1, mat=T)[fit1@control$fccolx,fit1@control$Cindex], dig=3)

# Shows B_1 matrix 
round(coef(fit1, mat=T)[fit1@control$fcolx,], dig=3)

# Show an A matrix 
round(fit1@constraints[[fit1@control$fccolx[1]]], dig=3)

# Easier 
print(biplot(fit1, plot=F))


sfit1 = summary(fit1)
sfit1
(se.orig = sqrt(diag(sfit1@cov.unscaled)))

# Rank-2 RR-MLM
set.seed(123)
fit2 = rrvglm(marital ~ age30 + logedu1 + 
                        binge + smokenow + sun + nerves + nervous + 
                        hurt + tense + miserable + fedup +
                        worry + worrier + mood,
              multinomial,
              norrr = ~ age30 + logedu1,
              rank=2,
              Crit="coef", linesearch=F,
              Cindex=1:2,
              maxit=7, eps=1e-8,
              data=workforce, trace=T, cr="dev")


postscript('./marital.eps', horiz=F,
           width=8.6, height=4.8,
           onefile=FALSE, print.it=FALSE)
par(las=1, mar=c(2,3,0.1,1)+0.1)
# lvplot(fit2) # lvplot looks bivariate normal...boring

temp = biplot(fit2, plot.it=F) 
# Some of the labelling is clustered so need to make them nice manually
alabels = names(temp$fccolx) 
delta    = rep(0.04, length(alabels))   # default 
names(delta)   = alabels
delta["sun"] = 0.12
delta["miserable"] = 0.06
delta["nerves"] = 0.07
delta["mood"] = -0.03
delta["fedup"] = 0.12
delta["smokenow"] = 0.08
alabels[alabels=="binge"] = "     binge"  # Shift it to the right a bit 
alabels[alabels=="nerves"] = "nerves mood"
alabels[alabels=="fedup"] = " fed- \nup "
alabels[alabels=="mood"] = ""  # "                     "
alabels[alabels=="miserable"] = "miserable     "
alabels[alabels=="hurt"] = "           hurt"
# Names of alabels not important 
biplot(fit2, delta=delta, xlim=c(-0.3, 2.0), ylim=c(-0.3, 1.0),
       ccex=0.7, alabels=alabels)
dev.off() 


# Look at the AIC 

Devs = c(4194.689, 4120.695, 4102.293, 4095.043)
M = 3
r <- 0:3   # ranks to choose from
p1 = 3 # including the intercept
p2 = 12
np = (M-r)*r + M*p1 + p2*r    # number of parameters
my.aic = Devs + 2 * np
cbind(r, my.aic, np)



q() 


